@@ -9,10 +9,12 @@ from PyFin.DateUtilities.Calendar import Calendar
 from PyFin.DateUtilities.Date import Date
 from PyFin.DateUtilities.Date import check_date
 from PyFin.DateUtilities.Period import Period
+from PyFin.DateUtilities.Period import check_period
 from PyFin.DateUtilities.Schedule import Schedule
 
 __all__ = ['Calendar',
            'Date',
            'Period',
            'Schedule',
-           'check_date']
+           'check_date',
+           'check_period']
