@@ -33,6 +33,7 @@ from PyFin.Analysis.TechnicalAnalysis import SecurityTimeMovingCountUnique
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingAllTrue
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingAnyTrue
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingSum
+from PyFin.Analysis.TechnicalAnalysis import SecurityTimeMovingSum
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingCountedPositive
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingPositiveAverage
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingPositiveDifferenceAverage
@@ -287,7 +288,7 @@ class TestStatefulTechnicalAnalysis(unittest.TestCase):
                                                                  'calculated: {2:.12f}'.format(i, expected,
                                                                                                calculated))
 
-    def testSecurityTimeMovingAverage(self):
+    def testSecurityTimeMovingStandardDeviation(self):
         window = 60
         ma1 = SecurityTimeMovingStandardDeviation(window, ['close'])
 
@@ -761,6 +762,32 @@ class TestStatefulTechnicalAnalysis(unittest.TestCase):
                                                                  'expected:   {1:.12f}\n'
                                                                  'calculated: {2:.12f}'.format(i, expected, calculated))
 
+    def testSecurityTimeMovingSum(self):
+        window = 60
+        ma1 = SecurityTimeMovingSum(window, ['close'])
+
+        for i in range(len(self.aapl['close'])):
+            data = dict(aapl=dict(close=self.aapl['close'][i],
+                                  open=self.aapl['open'][i],
+                                  stamp=self.aapl["stamp"][i]),
+                        ibm=dict(close=self.ibm['close'][i],
+                                 open=self.ibm['open'][i],
+                                 stamp=self.ibm["stamp"][i]))
+            ma1.push(data)
+            value = ma1.value
+
+            if i <= 1:
+                continue
+
+            for name in value.index():
+                time_diff = (getattr(self, name)["stamp"][i] - getattr(self, name)["stamp"]) < window
+                time_diff[i + 1:] = False
+                expected = np.sum(self.dataSet[name]['close'][time_diff])
+                calculated = value[name]
+                self.assertAlmostEqual(expected, calculated, 12, 'at index {0}\n'
+                                                                 'expected:   {1:.12f}\n'
+                                                                 'calculated: {2:.12f}'.format(i, expected, calculated))
+
     def testSecurityMovingSumDeepcopy(self):
         self.template_test_deepcopy(SecurityMovingSum, window=10, x='x')
 
