@@ -18,6 +18,7 @@ from PyFin.Analysis.CrossSectionValueHolders import CSBottomNPercentileSecurityV
 from PyFin.Analysis.CrossSectionValueHolders import CSAverageSecurityValueHolder
 from PyFin.Analysis.CrossSectionValueHolders import CSAverageAdjustedSecurityValueHolder
 from PyFin.Analysis.CrossSectionValueHolders import CSZScoreSecurityValueHolder
+from PyFin.Analysis.CrossSectionValueHolders import CSFillNASecurityValueHolder
 from PyFin.Analysis.CrossSectionValueHolders import CSPercentileSecurityValueHolder
 from PyFin.Analysis.CrossSectionValueHolders import CSResidueSecurityValueHolder
 
@@ -26,13 +27,16 @@ class TestCrossSectionValueHolder(unittest.TestCase):
 
     def setUp(self):
         np.random.seed(0)
-        sample1 = np.random.randn(1000, 4)
-        sample2 = np.random.randn(1000, 4)
+        sample1 = np.random.randn(1000, 6)
+        sample2 = np.random.randn(1000, 6)
 
         self.datas = {'aapl': {'close': sample1[:, 0], 'open': sample1[:, 1]},
                       'ibm': {'close': sample2[:, 0], 'open': sample2[:, 1]},
                       'goog': {'close': sample1[:, 2], 'open': sample1[:, 3]},
-                      'baba': {'close': sample2[:, 2], 'open': sample2[:, 3]}}
+                      'baba': {'close': sample2[:, 2], 'open': sample2[:, 3]},
+                      'tela': {'close': sample1[:, 4], 'open': sample1[:, 5]},
+                      'nflx': {'close': sample2[:, 4], 'open': sample2[:, 5]}
+                      }
 
     def testCSRankedSecurityValueHolderWithSymbolName(self):
         benchmark = SecurityLatestValueHolder(x='close')
@@ -318,6 +322,43 @@ class TestCrossSectionValueHolder(unittest.TestCase):
 
         np.testing.assert_array_almost_equal(expected, calculated.values)
 
+    def testCSFillNASecurityValueHolder(self):
+        benchmark = SecurityLatestValueHolder(x='close')
+        groups = SecurityLatestValueHolder(x='ind')
+        meanAdjustedHolder = CSFillNASecurityValueHolder(benchmark, groups)
+
+        def cal_func(x):
+            x[np.isnan(x)] = np.nanmean(x)
+            return x
+
+        for i in range(len(self.datas['aapl']['close'])):
+            data = {'aapl': {Factors.CLOSE: self.datas['aapl'][Factors.CLOSE][i],
+                             Factors.OPEN: self.datas['aapl'][Factors.OPEN][i],
+                             'ind': 1.},
+                    'ibm': {Factors.CLOSE: self.datas['ibm'][Factors.CLOSE][i],
+                            Factors.OPEN: self.datas['ibm'][Factors.OPEN][i],
+                            'ind': 1.},
+                    'tela': {Factors.CLOSE: np.nan,
+                            Factors.OPEN: self.datas['tela'][Factors.OPEN][i],
+                            'ind': 1.},
+                    'goog': {Factors.CLOSE: self.datas['goog'][Factors.CLOSE][i],
+                             Factors.OPEN: self.datas['goog'][Factors.OPEN][i],
+                             'ind': 2.},
+                    'baba': {Factors.CLOSE: np.nan,
+                             Factors.OPEN: self.datas['baba'][Factors.OPEN][i],
+                             'ind': 2.},
+                    'nflx': {Factors.CLOSE: self.datas['nflx'][Factors.CLOSE][i],
+                             Factors.OPEN: self.datas['nflx'][Factors.OPEN][i],
+                             'ind': 2.}
+                    }
+            benchmark.push(data)
+            meanAdjustedHolder.push(data)
+            benchmarkValues = benchmark.value
+            groups = {'aapl': 1., 'ibm': 1., 'tela': 1., 'goog': 2., 'baba': 2., 'nflx': 2.}
+            expected_rank = pd.Series(benchmarkValues.to_dict()).groupby(groups) \
+                .transform(cal_func)
+            np.testing.assert_array_almost_equal(expected_rank, meanAdjustedHolder.value.values)
+
     def testCSZscoreSecurityValueHolderWithGroups(self):
         benchmark = SecurityLatestValueHolder(x='close')
         groups = SecurityLatestValueHolder(x='ind')
@@ -367,6 +408,3 @@ class TestCrossSectionValueHolder(unittest.TestCase):
             beta = np.dot(np.linalg.inv(np.dot(x_values.T, x_values)), np.dot(x_values.T, y_values.reshape(-1, 1)))
             expected = y_values - np.dot(x_values, beta).flatten()
             np.testing.assert_array_almost_equal(calculated, expected)
-
-
-
