@@ -5,12 +5,14 @@ Created on 2015-8-8
 @author: cheng.li
 """
 
+from PyFin.tests.Math.Accumulators.testAccumulatorImpl import TestAccumulatorImpl
 from PyFin.tests.Math.Accumulators.testAccumulatorsArithmetic import TestAccumulatorsArithmetic
 from PyFin.tests.Math.Accumulators.testStatelessAccumulators import TestStatelessAccumulators
 from PyFin.tests.Math.Accumulators.testStatefulAccumulators import TestStatefulAccumulators
 from PyFin.tests.Math.Accumulators.testPerformancers import TestPerformancers
 
-__all__ = ['TestAccumulatorsArithmetic',
+__all__ = ['TestAccumulatorImpl',
+           'TestAccumulatorsArithmetic',
            'TestStatelessAccumulators',
            'TestStatefulAccumulators',
            'TestPerformancers']
